@@ -12,16 +12,23 @@ from astropy.coordinates.baseframe import BaseCoordinateFrame, RepresentationMap
 from astropy.coordinates.representation import (CartesianRepresentation, SphericalRepresentation,
                                                 CylindricalRepresentation,
                                                 UnitSphericalRepresentation)
+from astropy.time import Time
 
 from sunpy.sun.constants import radius as _RSUN
-
-from .frameattributes import TimeFrameAttributeSunPy, ObserverCoordinateAttribute
-
 from sunpy.util.decorators import add_common_docstring
 from sunpy.time.time import _variables_for_parse_time_docstring
 
+from .frameattributes import TimeFrameAttributeSunPy, ObserverCoordinateAttribute
+
+from sunpy.util.decorators import add_common_docstring, deprecated
+from sunpy.time.time import _variables_for_parse_time_docstring
+
+_J2000 = Time('J2000.0', scale='tt')
+
 __all__ = ['HeliographicStonyhurst', 'HeliographicCarrington',
-           'Heliocentric', 'Helioprojective']
+           'Heliocentric', 'Helioprojective',
+           'HeliocentricEarthEcliptic', 'GeocentricSolarEcliptic',
+           'HeliocentricInertial', 'GeocentricEarthEquatorial']
 
 
 def _frame_parameters():
@@ -58,6 +65,12 @@ def _frame_parameters():
     ret['radius'] = ("radius : `~astropy.units.Quantity`, optional\n"
                      "        The radial distance coordinate from Sun center for this object.\n"
                      "        Defaults to the radius of the Sun. Not needed if ``data`` is given.")
+    ret['distance_sun'] = ("distance : `~astropy.units.Quantity`, optional\n"
+                           "        The distance coordinate from Sun center for this object.\n"
+                           "        Not needed if ``data`` is given.")
+    ret['distance_earth'] = ("distance : `~astropy.units.Quantity`, optional\n"
+                             "        The distance coordinate from Earth center for this object.\n"
+                             "        Not needed if ``data`` is given.")
     ret['xyz'] = ("x : `~astropy.units.Quantity`, optional\n"
                   "        X-axis coordinate for this object. Not needed if ``data`` is given.\n"
                   "    y : `~astropy.units.Quantity`, optional\n"
@@ -69,6 +82,9 @@ def _frame_parameters():
                        "        it must be a solar system body that can be parsed by\n"
                        "        `~sunpy.coordinates.ephemeris.get_body_heliographic_stonyhurst`\n"
                        "        at the time ``obstime``. Defaults to Earth center.")
+    ret['equinox'] = (f"equinox : {_variables_for_parse_time_docstring()['parse_time_types']}\n"
+                      "        The date for the mean vernal equinox.\n"
+                      "        Defaults to the J2000.0 equinox.")
 
     return ret
 
@@ -302,20 +318,19 @@ class Heliocentric(SunPyBaseCoordinateFrame):
     >>> import astropy.units as u
 
     >>> sc = SkyCoord(CartesianRepresentation(10*u.km, 1*u.km, 2*u.km),
-    ...               obstime="2011/01/05T00:00:50", frame="heliocentric")
+    ...               obstime="2011/01/05T00:00:50", observer="earth", frame="heliocentric")
     >>> sc
     <SkyCoord (Heliocentric: obstime=2011-01-05T00:00:50.000, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (x, y, z) in km
         (10., 1., 2.)>
 
-    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm, frame="heliocentric", obstime="2011/01/01T00:00:54")
-
+    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm,
+    ...               obstime="2011/01/01T00:00:54", observer="earth", frame="heliocentric")
     >>> sc
     <SkyCoord (Heliocentric: obstime=2011-01-01T00:00:54.000, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (x, y, z) in (km, m, cm)
         [(1., 3., 5.), (2., 4., 6.)]>
 
     >>> sc = SkyCoord(CylindricalRepresentation(10*u.km, 60*u.deg, 10*u.km),
-    ...               obstime="2011/01/05T00:00:50",
-    ...               frame="heliocentric")
+    ...               obstime="2011/01/05T00:00:50", observer="earth", frame="heliocentric")
     >>> sc
     <SkyCoord (Heliocentric: obstime=2011-01-05T00:00:50.000, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (x, y, z) in km
         (5., 8.66025404, 10.)>
@@ -326,7 +341,7 @@ class Heliocentric(SunPyBaseCoordinateFrame):
         CylindricalRepresentation: [RepresentationMapping('phi', 'psi', u.deg)]
     }
 
-    observer = ObserverCoordinateAttribute(HeliographicStonyhurst, default="earth")
+    observer = ObserverCoordinateAttribute(HeliographicStonyhurst)
 
 
 @add_common_docstring(**_frame_parameters())
@@ -373,18 +388,18 @@ class Helioprojective(SunPyBaseCoordinateFrame):
     >>> from astropy.coordinates import SkyCoord
     >>> import sunpy.coordinates
     >>> import astropy.units as u
-    >>> sc = SkyCoord(0*u.deg, 0*u.deg, 5*u.km, obstime="2010/01/01T00:00:00",
-    ...               frame="helioprojective")
+    >>> sc = SkyCoord(0*u.deg, 0*u.deg, 5*u.km,
+    ...               obstime="2010/01/01T00:00:00", observer="earth", frame="helioprojective")
     >>> sc
     <SkyCoord (Helioprojective: obstime=2010-01-01T00:00:00.000, rsun=695700.0 km, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (Tx, Ty, distance) in (arcsec, arcsec, km)
         (0., 0., 5.)>
-    >>> sc = SkyCoord(0*u.deg, 0*u.deg, obstime="2010/01/01T00:00:00", frame="helioprojective")
+    >>> sc = SkyCoord(0*u.deg, 0*u.deg,
+    ...               obstime="2010/01/01T00:00:00", observer="earth", frame="helioprojective")
     >>> sc
     <SkyCoord (Helioprojective: obstime=2010-01-01T00:00:00.000, rsun=695700.0 km, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (Tx, Ty) in arcsec
         (0., 0.)>
     >>> sc = SkyCoord(CartesianRepresentation(1*u.AU, 1e5*u.km, -2e5*u.km),
-    ...               obstime="2011/01/05T00:00:50",
-    ...               frame="helioprojective")
+    ...               obstime="2011/01/05T00:00:50", observer="earth", frame="helioprojective")
     >>> sc
     <SkyCoord (Helioprojective: obstime=2011-01-05T00:00:50.000, rsun=695700.0 km, observer=<HeliographicStonyhurst Coordinate for 'earth'>): (Tx, Ty, distance) in (arcsec, arcsec, AU)
         (137.87948623, -275.75878762, 1.00000112)>
@@ -411,19 +426,18 @@ class Helioprojective(SunPyBaseCoordinateFrame):
     }
 
     rsun = Attribute(default=_RSUN.to(u.km))
-    observer = ObserverCoordinateAttribute(HeliographicStonyhurst, default="earth")
+    observer = ObserverCoordinateAttribute(HeliographicStonyhurst)
 
-    def calculate_distance(self):
+    def make_3d(self):
         """
         This method calculates the third coordinate of the Helioprojective
-        frame. It assumes that the coordinate point is on the disk of the Sun
-        at the rsun radius.
+        frame. It assumes that the coordinate point is on the surface of the Sun.
 
         If a point in the frame is off limb then NaN will be returned.
 
         Returns
         -------
-        new_frame : `~sunpy.coordinates.frames.HelioProjective`
+        new_frame : `~sunpy.coordinates.frames.Helioprojective`
             A new frame instance with all the attributes of the original but
             now with a third coordinate.
         """
@@ -433,9 +447,9 @@ class Helioprojective(SunPyBaseCoordinateFrame):
             return self
 
         if not isinstance(self.observer, BaseCoordinateFrame):
-            raise ConvertError("Cannot calculate distance to the solar disk "
-                               "for observer '{}' "
-                               "without `obstime` being specified.".format(self.observer))
+            raise ConvertError("Cannot calculate distance to the Sun "
+                               f"for observer '{self.observer}' "
+                               "without `obstime` being specified.")
 
         rep = self.represent_as(UnitSphericalRepresentation)
         lat, lon = rep.lat, rep.lon
@@ -449,3 +463,104 @@ class Helioprojective(SunPyBaseCoordinateFrame):
         return self.realize_frame(SphericalRepresentation(lon=lon,
                                                           lat=lat,
                                                           distance=d))
+
+    # Support the previous name for make_3d for now
+    calculate_distance = deprecated('1.1', name="calculate_distance",
+                                    alternative="make_3d")(make_3d)
+
+
+@add_common_docstring(**_frame_parameters())
+class HeliocentricEarthEcliptic(SunPyBaseCoordinateFrame):
+    """
+    A coordinate or frame in the Heliocentric Earth Ecliptic (HEE) system.
+
+    - The origin is the center of the Sun.
+    - The X-axis (0 degrees longitude and 0 degrees latitude) is aligned with the Sun-Earth line.
+    - The Z-axis (+90 degrees latitude) is aligned with the component perpendicular to the X-axis
+      of the mean ecliptic pole at the observation time.
+
+    Parameters
+    ----------
+    {data}
+    {lonlat}
+    {distance_sun}
+    {common}
+    """
+    default_representation = SphericalRepresentation
+
+
+@add_common_docstring(**_frame_parameters())
+class GeocentricSolarEcliptic(SunPyBaseCoordinateFrame):
+    """
+    A coordinate or frame in the Geocentric Solar Ecliptic (GSE) system.
+
+    - The origin is the center of the Earth.
+    - The X-axis (0 degrees longitude and 0 degrees latitude) is aligned with the Earth-Sun line.
+    - The Z-axis (+90 degrees latitude) is aligned with the component perpendicular to the X-axis
+      of the mean ecliptic pole at the observation time.
+
+    Parameters
+    ----------
+    {data}
+    {lonlat}
+    {distance_earth}
+    {common}
+
+    Notes
+    -----
+    Aberration due to Earth motion is not included.
+    """
+    default_representation = SphericalRepresentation
+
+
+@add_common_docstring(**_frame_parameters())
+class HeliocentricInertial(SunPyBaseCoordinateFrame):
+    """
+    A coordinate or frame in the Heliocentric Inertial (HCI) system.
+
+    - The origin is the center of the Sun.
+    - The Z-axis (+90 degrees latitude) is aligned with the Sun's north pole.
+    - The X-axis (0 degrees longitude and 0 degrees latitude) is aligned with the solar ascending
+      node on the ecliptic (mean J2000.0).
+
+    Parameters
+    ----------
+    {data}
+    {lonlat}
+    {distance_sun}
+    {common}
+
+    Notes
+    -----
+    The solar ascending node on the ecliptic lies on the intersection of the solar equatorial
+    plane with the ecliptic plane, not on the intersection of the celestial equatorial plane with
+    the ecliptic plane.
+    """
+    default_representation = SphericalRepresentation
+
+
+@add_common_docstring(**_frame_parameters())
+class GeocentricEarthEquatorial(SunPyBaseCoordinateFrame):
+    """
+    A coordinate or frame in the Geocentric Earth Equatorial (GEI) system.
+
+    - The origin is the center of the Earth.
+    - The Z-axis (+90 degrees latitude) is aligned with the Earth's north pole.
+    - The X-axis (0 degrees longitude and 0 degrees latitude) is aligned with the mean (not true)
+      vernal equinox.
+
+    Parameters
+    ----------
+    {data}
+    {lonlat}
+    {distance_earth}
+    {equinox}
+    {common}
+
+    Notes
+    -----
+    Aberration due to Earth motion is not included.
+    """
+    default_representation = SphericalRepresentation
+
+    equinox = TimeFrameAttributeSunPy(default=_J2000)
